==> shande-sdk-1.0.0.20221202-sources.jar: com/fshows/com/shande/openapi/sdk/constant/RequestConstants.java <==
package com.fshows.com.shande.openapi.sdk.constant;

/**
 * 请求常量类
 *
 * @author miwenming
 * @date 2020/5/19 15:53
 */
public class RequestConstants {

    /**
     * 请求头
     */
    public class RequestHeader {
        /**
         * 算法服务标识-KEY
         */
        public static final String KEY_ALGORITHM = "algorithm";

        /** 服务唯一标识 */
        public static final String KEY_API_NAME = "api_name";

        /** 子服务编号 */
        public static final String KEY_API_CODE = "api_code";

        /** 服务版本 */
        public static final String KEY_API_VERSION = "api_version";

        /** 请求流水号 */
        public static final String KEY_CLIENT_SERIAL_NO = "client_serial_no";
    }

    /**
     * 请求体
     */
    public class RequestBody {

        /**
         * 商户号
         */
        public static final String KEY_MID = "mid";

        /**
         * 签名数据
         */
        public static final String KEY_SIGN = "sign";

        /**
         * 请求时间戳
         */
        public static final String KEY_TIMESTAMP = "timestamp";

        /**
         * SDK版本
         */
        public static final String KEY_VERSION = "version";

        /**
         * 商户号下每次请求的唯一流水号
         */
        public static final String KEY_CUSTOMER_ORDER_NO = "customerOrderNo";

        /**
         * 签名类型
         */
        public static final String KEY_SIGN_TYPE = "signType";

        /**
         * 加密类型
         */
        public static final String KEY_ENCRYPT_TYPE = "encryptType";

        /**
         * 经过RSA加密后的AES加密随机密钥
         */
        public static final String KEY_ENCRYPT_KEY = "encryptKey";

        /**
         * 待加密或已加密业务数据
         */
        public static final String KEY_DATA = "data";
    }

    /**
     * 响应体
     */
    public class ResponseBody {

        /**
         * 响应时间戳
         */
        public static final String KEY_TIMESTAMP = "responseTime";

        /**
         * 商户号下每次请求的唯一流水号
         */
        public static final String KEY_CUSTOMER_ORDER_NO = "customerOrderNo";

        /**
         * 待加密或已加密业务数据
         */
        public static final String KEY_DATA = "data";

        /**
         * 待加密或已加密业务数据
         */
        public static final String KEY_RESPONSE_CODE = "responseCode";

        /**
         * 待加密或已加密业务数据
         */
        public static final String KEY_RESPONSE_DESC = "responseDesc";
    }

    /**
     * 请求业务参数
     */
    public class RequestData {
        /**
         * 文件下载业务参数
         */
        public static final String BIZ_DATA = "bizData";
    }

    /**
     * 算法服务实现
     */
    public class AlgorithmService {
        /**
         * 服务算法标识-VALUE，rsaDetached表示双证书且安全加固
         **/
        public static final String ALGORITHM_TYPE_RSA_DETACHED = "rsaDetached";

        /**
         * 服务算法标识-VALUE，rsaService表示双证书
         **/
        public static final String ALGORITHM_TYPE_RSA = "rsaService";

        /**
         * 服务算法标识-VALUE，fileDownload表示文件下载
         **/
        public static final String ALGORITHM_TYPE_RSA_FILE = "fileDownload";
    }

    /**
     * SDK信息常量
     */
    public class SDK {
        public static final String VERSION = "1.0.0";
    }

}

==> shande-sdk-1.0.0.20230410-20230331.021633-1-sources.jar: com/fshows/com/shande/openapi/sdk/constant/RequestConstants.java <==
package com.fshows.com.shande.openapi.sdk.constant;

/**
 * 请求常量类
 *
 * @author miwenming
 * @date 2020/5/19 15:53
 */
public class RequestConstants {

    /**
     * 请求头
     */
    public class RequestHeader {
        /**
         * 算法服务标识-KEY
         */
        public static final String KEY_ALGORITHM = "algorithm";

        /** 服务唯一标识 */
        public static final String KEY_API_NAME = "api_name";

        /** 子服务编号 */
        public static final String KEY_API_CODE = "api_code";

        /** 服务版本 */
        public static final String KEY_API_VERSION = "api_version";

        /** 请求流水号 */
        public static final String KEY_CLIENT_SERIAL_NO = "client_serial_no";
    }

    /**
     * 请求体
     */
    public class RequestBody {

        /**
         * 商户号
         */
        public static final String KEY_MID = "mid";

        /**
         * 签名数据
         */
        public static final String KEY_SIGN = "sign";

        /**
         * 请求时间戳
         */
        public static final String KEY_TIMESTAMP = "timestamp";

        /**
         * SDK版本
         */
        public static final String KEY_VERSION = "version";

        /**
         * 商户号下每次请求的唯一流水号
         */
        public static final String KEY_CUSTOMER_ORDER_NO = "customerOrderNo";

        /**
         * 签名类型
         */
        public static final String KEY_SIGN_TYPE = "signType";

        /**
         * 加密类型
         */
        public static final String KEY_ENCRYPT_TYPE = "encryptType";

        /**
         * 经过RSA加密后的AES加密随机密钥
         */
        public static final String KEY_ENCRYPT_KEY = "encryptKey";

        /**
         * 待加密或已加密业务数据
         */
        public static final String KEY_DATA = "data";
    }

    /**
     * 响应体
     */
    public class ResponseBody {

        /**
         * 响应时间戳
         */
        public static final String KEY_TIMESTAMP = "responseTime";
        /**
         * 第三方业务请求处理失败错误码
         */
        public static final String KEY_CODE = "code";
        /**
         * 第三方业务请求处理失败信息
         */
        public static final String KEY_ISSUE = "issue";

        /**
         * 第三方业务请求处理失败信息
         */
        public static final String KEY_MESSAGE = "message";

        /**
         * 商户号下每次请求的唯一流水号
         */
        public static final String KEY_CUSTOMER_ORDER_NO = "customerOrderNo";

        /**
         * 待加密或已加密业务数据
         */
        public static final String KEY_DATA = "data";

        /**
         * 待加密或已加密业务数据
         */
        public static final String KEY_RESPONSE_CODE = "responseCode";

        /**
         * 待加密或已加密业务数据
         */
        public static final String KEY_RESPONSE_DESC = "responseDesc";
    }

    /**
     * 请求业务参数
     */
    public class RequestData {
        /**
         * 文件下载业务参数
         */
        public static final String BIZ_DATA = "bizData";
    }

    /**
     * 算法服务实现
     */
    public class AlgorithmService {
        /**
         * 服务算法标识-VALUE，rsaDetached表示双证书且安全加固
         **/
        public static final String ALGORITHM_TYPE_RSA_DETACHED = "rsaDetached";

        /**
         * 服务算法标识-VALUE，rsaService表示双证书
         **/
        public static final String ALGORITHM_TYPE_RSA = "rsaService";

        /**
         * 服务算法标识-VALUE，fileDownload表示文件下载
         **/
        public static final String ALGORITHM_TYPE_RSA_FILE = "fileDownload";
    }

    /**
     * SDK信息常量
     */
    public class SDK {
        public static final String VERSION = "1.0.0";
    }

}
